==> zio-aws-servicecatalog_2.13-5.17.112.1-sources.jar: zio/aws/servicecatalog/model/DescribeConstraintResponse.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.servicecatalog.model.primitives.ConstraintParameters
import scala.jdk.CollectionConverters._
final case class DescribeConstraintResponse(
    constraintDetail: Option[zio.aws.servicecatalog.model.ConstraintDetail] =
      None,
    constraintParameters: Option[ConstraintParameters] = None,
    status: Option[zio.aws.servicecatalog.model.Status] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.DescribeConstraintResponse = {
    import DescribeConstraintResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.DescribeConstraintResponse
      .builder()
      .optionallyWith(constraintDetail.map(value => value.buildAwsValue()))(
        _.constraintDetail
      )
      .optionallyWith(
        constraintParameters.map(value =>
          ConstraintParameters.unwrap(value): java.lang.String
        )
      )(_.constraintParameters)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.DescribeConstraintResponse.ReadOnly =
    zio.aws.servicecatalog.model.DescribeConstraintResponse
      .wrap(buildAwsValue())
}
object DescribeConstraintResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.DescribeConstraintResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.servicecatalog.model.DescribeConstraintResponse =
      zio.aws.servicecatalog.model.DescribeConstraintResponse(
        constraintDetail.map(value => value.asEditable),
        constraintParameters.map(value => value),
        status.map(value => value)
      )
    def constraintDetail
        : Option[zio.aws.servicecatalog.model.ConstraintDetail.ReadOnly]
    def constraintParameters: Option[ConstraintParameters]
    def status: Option[zio.aws.servicecatalog.model.Status]
    def getConstraintDetail: ZIO[
      Any,
      AwsError,
      zio.aws.servicecatalog.model.ConstraintDetail.ReadOnly
    ] = AwsError.unwrapOptionField("constraintDetail", constraintDetail)
    def getConstraintParameters: ZIO[Any, AwsError, ConstraintParameters] =
      AwsError.unwrapOptionField("constraintParameters", constraintParameters)
    def getStatus: ZIO[Any, AwsError, zio.aws.servicecatalog.model.Status] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.DescribeConstraintResponse
  ) extends zio.aws.servicecatalog.model.DescribeConstraintResponse.ReadOnly {
    override val constraintDetail
        : Option[zio.aws.servicecatalog.model.ConstraintDetail.ReadOnly] = scala
      .Option(impl.constraintDetail())
      .map(value => zio.aws.servicecatalog.model.ConstraintDetail.wrap(value))
    override val constraintParameters: Option[ConstraintParameters] = scala
      .Option(impl.constraintParameters())
      .map(value =>
        zio.aws.servicecatalog.model.primitives.ConstraintParameters(value)
      )
    override val status: Option[zio.aws.servicecatalog.model.Status] = scala
      .Option(impl.status())
      .map(value => zio.aws.servicecatalog.model.Status.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.DescribeConstraintResponse
  ): zio.aws.servicecatalog.model.DescribeConstraintResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-servicecatalog_2.13-7.21.15.2-sources.jar: zio/aws/servicecatalog/model/DescribeConstraintResponse.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.servicecatalog.model.primitives.ConstraintParameters
import scala.jdk.CollectionConverters._
final case class DescribeConstraintResponse(
    constraintDetail: Optional[zio.aws.servicecatalog.model.ConstraintDetail] =
      Optional.Absent,
    constraintParameters: Optional[ConstraintParameters] = Optional.Absent,
    status: Optional[zio.aws.servicecatalog.model.Status] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.DescribeConstraintResponse = {
    import DescribeConstraintResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.DescribeConstraintResponse
      .builder()
      .optionallyWith(constraintDetail.map(value => value.buildAwsValue()))(
        _.constraintDetail
      )
      .optionallyWith(
        constraintParameters.map(value =>
          ConstraintParameters.unwrap(value): java.lang.String
        )
      )(_.constraintParameters)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.DescribeConstraintResponse.ReadOnly =
    zio.aws.servicecatalog.model.DescribeConstraintResponse
      .wrap(buildAwsValue())
}
object DescribeConstraintResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.DescribeConstraintResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.servicecatalog.model.DescribeConstraintResponse =
      zio.aws.servicecatalog.model.DescribeConstraintResponse(
        constraintDetail.map(value => value.asEditable),
        constraintParameters.map(value => value),
        status.map(value => value)
      )
    def constraintDetail
        : Optional[zio.aws.servicecatalog.model.ConstraintDetail.ReadOnly]
    def constraintParameters: Optional[ConstraintParameters]
    def status: Optional[zio.aws.servicecatalog.model.Status]
    def getConstraintDetail: ZIO[
      Any,
      AwsError,
      zio.aws.servicecatalog.model.ConstraintDetail.ReadOnly
    ] = AwsError.unwrapOptionField("constraintDetail", constraintDetail)
    def getConstraintParameters: ZIO[Any, AwsError, ConstraintParameters] =
      AwsError.unwrapOptionField("constraintParameters", constraintParameters)
    def getStatus: ZIO[Any, AwsError, zio.aws.servicecatalog.model.Status] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.DescribeConstraintResponse
  ) extends zio.aws.servicecatalog.model.DescribeConstraintResponse.ReadOnly {
    override val constraintDetail
        : Optional[zio.aws.servicecatalog.model.ConstraintDetail.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.constraintDetail())
        .map(value => zio.aws.servicecatalog.model.ConstraintDetail.wrap(value))
    override val constraintParameters: Optional[ConstraintParameters] =
      zio.aws.core.internal
        .optionalFromNullable(impl.constraintParameters())
        .map(value =>
          zio.aws.servicecatalog.model.primitives.ConstraintParameters(value)
        )
    override val status: Optional[zio.aws.servicecatalog.model.Status] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.servicecatalog.model.Status.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.DescribeConstraintResponse
  ): zio.aws.servicecatalog.model.DescribeConstraintResponse.ReadOnly =
    new Wrapper(impl)
}
